# Internal Reference

## Julia Interface

::: pysr.julia_helpers
    options:
        members:
            - init_julia
            - install
        heading_level: 3

## Exporting to LaTeX

::: pysr.export_latex
    options:
        members:
            - to_latex
            - generate_single_table
            - generate_multiple_tables
            - generate_table_environment
        heading_level: 3

## Exporting to JAX

::: pysr.export_jax
    options:
        members:
            - sympy2jax
            - sympy2jaxtext
        heading_level: 3

## Exporting to PyTorch

::: pysr.export_torch
    options:
        members:
            - sympy2torch
        heading_level: 3
